@@ -161,7 +161,7 @@ $VERSION = '1.17';
         'MakerNoteKodak6a',
         'MakerNoteKodak6b',
         'MakerNoteKodak7',
-        'MakerNoteKodakIFD',
+        'MakerNoteKodak8',
         'MakerNoteKodakUnknown',
         'MakerNoteKyocera',
         'MakerNoteMinolta',
@@ -173,6 +173,8 @@ $VERSION = '1.17';
         'MakerNoteOlympus',
         'MakerNoteOlympus2',
         'MakerNoteLeica',
+        'MakerNoteLeica2',
+        'MakerNoteLeica3',
         'MakerNotePanasonic',
         'MakerNotePanasonic2',
         'MakerNotePentax',
